import { HTMLAttributes, ReactNode } from 'react';
export type LayoutProps = {
    /** Whether the header should stick to the top of the viewport, hiding/showing as the user scrolls down/up. Defaults to `false`. */
    headerSticky?: boolean;
    /** Whether the header should be overlaid on top of the page's content. Defaults to `false`, meaning it occupies space on the page and pushes the main section down. */
    headerOverlay?: boolean;
    /** Slot for the header's content. Should contain a `Navigation` component. */
    headerContent: ReactNode;
    /** Whether the main section should be wrapped in a centered container with a maximum width and left/right padding (like the header and footer are). Defaults to `false`. */
    mainContainer?: boolean;
    /** Slot for the footer's content. Should contain a `Footer` component. */
    footerContent: ReactNode;
} & HTMLAttributes<HTMLElement>;
/**
 * Component for a page layout with a header, a main section, and a footer. The header can be sticky (`headerSticky`) and/or appear over the main section (`headerOverlay`).
 */
export declare const Layout: ({ headerSticky, headerOverlay, headerContent, mainContainer, footerContent, children, ...props }: LayoutProps) => import("theme-ui/jsx-runtime").JSX.Element;
