/// <reference types="react" />
import type { Locale, Translations } from './types';
export type I18nContextData = {
    /** Array of `Locale`s that are supported by the current app or context. Defaults to all the locales that exist in `components`. */
    supportedLocales: Locale[];
    /** App-specific translations indexed by locale (e.g. `{ en: { key: 'Value in English' }, fr: { key: 'Value in French' } }`). Merged into the default translations from `components`. */
    translations: Translations;
    /** Current locale, i.e. the current URL's locale, or (if there's no locale in the URL) the user's preferred locale, or (if it's not supported or cannot be determined) the default locale (English). */
    locale: Locale;
    /** Function that should change the value of `locale`. */
    setLocale: (locale: Locale) => void;
    /** Part of the URL that follows the host + the current locale. */
    pathWithoutLocale: string;
};
export declare const I18nContextDataDefaults: I18nContextData;
export declare const I18nContext: import("react").Context<I18nContextData>;
