import { Language } from 'prism-react-renderer';
import { HTMLAttributes } from 'react';
import { TextProps } from '../../atoms';
export type CodeProps = {
    /** Component variant. One of `block` or `inline`. */
    variant: 'block' | 'inline';
    /** Code to render. */
    children: string;
    /** Language to use for syntax highlighting. Defaults to `plain` (no syntax highlighting). */
    language?: Language | 'plain';
    /** Font size. Inherited by default. */
    size?: TextProps['size'];
} & Omit<HTMLAttributes<HTMLElement>, 'children' | 'color'>;
/**
 * `Code` v1.0
 *
 * Renders a code block (with `Code.Block`) or an inline string of code (with `Code.Inline`).
 * Syntax highlighting is applied if a `language` is specified. The font size is inherited by default,
 * but can be set explicitly with the `size` prop.
 */
export declare const Code: import("react").ForwardRefExoticComponent<{
    /** Component variant. One of `block` or `inline`. */
    variant: 'block' | 'inline';
    /** Code to render. */
    children: string;
    /** Language to use for syntax highlighting. Defaults to `plain` (no syntax highlighting). */
    language?: Language | "plain" | undefined;
    /** Font size. Inherited by default. */
    size?: TextProps['size'];
} & Omit<HTMLAttributes<HTMLElement>, "children" | "color"> & import("react").RefAttributes<HTMLElement>> & {
    Block: import("react").ForwardRefExoticComponent<Omit<CodeProps, "variant"> & import("react").RefAttributes<HTMLPreElement>>;
    Inline: import("react").ForwardRefExoticComponent<Omit<CodeProps, "variant"> & import("react").RefAttributes<HTMLElement>>;
};
