import { ComponentPropsWithoutRef, ReactNode } from 'react';
export interface ExpandableContainerProps extends ComponentPropsWithoutRef<'div'> {
    css?: never;
}
/**
 * Used to expand content like Tables or Charts to fill available screen space,
 * when the screen is larger than the usual content container width.
 */
export declare function ExpandableContainer(props: ExpandableContainerProps): import("theme-ui/jsx-runtime").JSX.Element;
export declare namespace ExpandableContainer {
    var Provider: typeof ExpandableContainerProvider;
    var Toggle: typeof ExpandableContainerToggle;
}
export interface ExpandableContainerProviderProps {
    children: React.ReactNode;
    /** @default false */
    initialState?: boolean;
    /**
     * - If `true` the container will be expanded on screens narrower than 1st breakpoint, and the Toggle will be hidden.
     * - If `false`, it will be collapsed, and the Toggle will be hidden.
     * - If left unset or set to `undefined`, the Toggle will still be displayed, and `isExpanded` state is in play.
     *
     * @default `undefined`
     */
    isExpandedOnMobile?: boolean | undefined;
}
export declare function ExpandableContainerProvider({ children, initialState, isExpandedOnMobile, }: ExpandableContainerProviderProps): import("theme-ui/jsx-runtime").JSX.Element;
export interface ExpandableContainerToggleProps {
    children?: ReactNode;
}
export declare function ExpandableContainerToggle({ children }: ExpandableContainerToggleProps): import("theme-ui/jsx-runtime").JSX.Element;
