import { ElementType, LabelHTMLAttributes, ReactNode } from 'react';
import { SxColor } from '../../tokens';
export type LabelProps = {
    /** Element type to render. Defaults to `div`. */
    as?: ElementType;
    /** Label variant. One of `dim` or `bright`. Defaults to `dim`. */
    variant?: 'dim' | 'bright';
    /** Label size. One of `small` or `large`. Defaults to `small`. */
    size?: 'small' | 'large';
    /** Label color. Defaults to `TextDim` if `variant` is `dim`, or `TextBright` if it's `bright`. */
    color?: SxColor;
    /** Icon to render to the left of the label. */
    iconLeft?: ReactNode;
    /** Icon to render to the right of the label. */
    iconRight?: ReactNode;
} & Omit<LabelHTMLAttributes<HTMLLabelElement>, 'color'>;
/**
 * Labelling text, optionally with an icon on the left or on the right.
 * Can be an accessible label for a form element (e.g. `input`, `select`, etc.) if `htmlFor` is used.
 */
export declare const Label: import("react").ForwardRefExoticComponent<{
    /** Element type to render. Defaults to `div`. */
    as?: ElementType<any> | undefined;
    /** Label variant. One of `dim` or `bright`. Defaults to `dim`. */
    variant?: "dim" | "bright" | undefined;
    /** Label size. One of `small` or `large`. Defaults to `small`. */
    size?: "small" | "large" | undefined;
    /** Label color. Defaults to `TextDim` if `variant` is `dim`, or `TextBright` if it's `bright`. */
    color?: SxColor | undefined;
    /** Icon to render to the left of the label. */
    iconLeft?: ReactNode;
    /** Icon to render to the right of the label. */
    iconRight?: ReactNode;
} & Omit<LabelHTMLAttributes<HTMLLabelElement>, "color"> & import("react").RefAttributes<HTMLElement>>;
