import { HTMLAttributes } from 'react';
import { FontSize } from '../../tokens';
type Extends<T, U extends T> = U;
type ListSize = Extends<keyof typeof FontSize, '14px' | '16px' | '18px' | '20px' | '24px'>;
export type ListProps = {
    /** List variant. One of `numbers`, `arrows`, or `bullets`. */
    variant: 'numbers' | 'arrows' | 'bullets';
    /** Font size. One of `14px`, `16px`, `18px`, `20px`, or `24px`. Defaults to `18px`. */
    size?: ListSize;
} & HTMLAttributes<HTMLOListElement | HTMLUListElement>;
export declare const ListBase: import("react").ForwardRefExoticComponent<{
    /** List variant. One of `numbers`, `arrows`, or `bullets`. */
    variant: 'numbers' | 'arrows' | 'bullets';
    /** Font size. One of `14px`, `16px`, `18px`, `20px`, or `24px`. Defaults to `18px`. */
    size?: "24px" | "20px" | "18px" | "16px" | "14px" | undefined;
} & HTMLAttributes<HTMLOListElement | HTMLUListElement> & import("react").RefAttributes<HTMLOListElement | HTMLUListElement>>;
type ListItemProps = HTMLAttributes<HTMLLIElement>;
/**
 * `List` v1.0
 *
 * Vertical list of text items with 3 variants, representing the different types of item markers:
 * - `List.Numbers` (renders a `ol`)
 * - `List.Arrows` (renders a `ul`)
 * - `List.Bullets` (renders a `ul`)
 *
 * Child component: `List.Item` (renders a `li`)
 */
export declare const List: import("react").ForwardRefExoticComponent<{
    /** List variant. One of `numbers`, `arrows`, or `bullets`. */
    variant: 'numbers' | 'arrows' | 'bullets';
    /** Font size. One of `14px`, `16px`, `18px`, `20px`, or `24px`. Defaults to `18px`. */
    size?: "24px" | "20px" | "18px" | "16px" | "14px" | undefined;
} & HTMLAttributes<HTMLOListElement | HTMLUListElement> & import("react").RefAttributes<HTMLOListElement | HTMLUListElement>> & {
    Numbers: import("react").ForwardRefExoticComponent<Omit<ListProps, "variant"> & import("react").RefAttributes<HTMLUListElement>>;
    Arrows: import("react").ForwardRefExoticComponent<Omit<ListProps, "variant"> & import("react").RefAttributes<HTMLOListElement>>;
    Bullets: import("react").ForwardRefExoticComponent<Omit<ListProps, "variant"> & import("react").RefAttributes<HTMLOListElement>>;
    Item: ({ children, ...props }: ListItemProps) => import("theme-ui/jsx-runtime").JSX.Element | null;
};
export {};
