import { MenuSearchEmptyState, MenuSearchEmptyStateProps } from './MenuSearchEmptyState/MenuSearchEmptyState';
import { MenuCheckboxItem, MenuCheckboxItemProps } from './MenuCheckboxItem';
import { MenuGroupProps } from './MenuGroup';
import { MenuSearchInputProps } from './MenuSearchInput';
import { NewGDSDropdownButtonProps } from './NewGDSDropdownButton';
import { NewGDSDropdownMenuProps } from './NewGDSDropdownMenu';
import { NewGDSDropdownMenuItemProps } from './NewGDSDropdownMenuItem';
import { UncontrolledSearchMenu, UncontrolledSearchMenuProps } from './UncontrolledSearchMenu';
/**
 * Compound `NewGDSDropdown` component, mostly used to encapsulate the styles of a dropdown menu and its items.
 * The button that opens/closes the dropdown menu is left for implementation by the consumer.
 *
 * The `type` prop determines the semantics and behavior of the component:
 * - `menu` is for rendering a list of actions to execute, e.g. "View", "Edit" or "Delete".
 * - `select` is for rendering a list of options to select from, e.g. sort options (only one can be selected at a time).
 *
 * Child components: `NewGDSDropdown.Button`, `NewGDSDropdown.Menu`, and `NewGDSDropdown.Menu.Item`
 */
export declare const NewGDSDropdown: (<T extends import("./types").SelectValue>({ modal, children, ...props }: import("./NewGDSDropdownRoot").NewGDSDropdownRootProps<T>) => import("theme-ui/jsx-runtime").JSX.Element) & {
    Button: ({ asChild, disabled, children, ...props }: import("@radix-ui/react-dropdown-menu").DropdownMenuTriggerProps) => import("theme-ui/jsx-runtime").JSX.Element;
    Menu: (({ onCloseAutoFocus: onCloseAutoFocusOriginal, className, children, maxHeight, header, ...props }: NewGDSDropdownMenuProps) => import("theme-ui/jsx-runtime").JSX.Element) & {
        Item: ({ value, href, target, disabled, onSelect: onSelectOriginal, className, children, ...props }: NewGDSDropdownMenuItemProps) => import("theme-ui/jsx-runtime").JSX.Element;
        CheckboxItem: typeof MenuCheckboxItem;
        Group: ({ label, children, ...props }: MenuGroupProps) => import("theme-ui/jsx-runtime").JSX.Element;
        SearchInput: ({ value, onChange, placeholder, ...rest }: MenuSearchInputProps) => import("theme-ui/jsx-runtime").JSX.Element;
        SearchEmptyState: typeof MenuSearchEmptyState;
    };
    SearchMenu: typeof UncontrolledSearchMenu;
};
export type { NewGDSDropdownButtonProps, NewGDSDropdownMenuItemProps, NewGDSDropdownMenuProps, MenuCheckboxItemProps as NewGDSMenuCheckboxItemProps, MenuGroupProps as NewGDSMenuGroupProps, MenuSearchEmptyStateProps as NewGDSMenuSearchEmptyStateProps, MenuSearchInputProps as NewGDSMenuSearchInputProps, UncontrolledSearchMenuProps as NewGDSMenuUncontrolledSearchProps, };
