import { CSSProperties, ReactNode } from 'react';
import { PaginationNav } from './PaginationNav';
export type { PaginationNavProps } from './PaginationNav';
export type { PaginationPageSizeSelectProps } from './PaginationPageSizeSelect';
export interface PaginationProps {
    /**
     * Pagination.Nav and optionally Pagination.PageSizeSelect
     *
     * @example
     *  <Pagination.Nav
     *    current={page}
     *    total={total}
     *    linkProps={({ page }) => ({
     *      href: `?page=${page}`,
     *      onClick: () => setPage(page),
     *    })}
     *  />
     *  <Pagination.PaginationPageSizeSelect
     *    value={pageSize}
     *    onChange={setPageSize}
     *    total={total}
     *  />
     */
    children: ReactNode;
    /** aria-label for the section */
    label: string;
    /** optional styles for the section */
    className?: string;
    /** optional styles for the section */
    style?: CSSProperties;
}
export declare function Pagination({ children, label, ...rest }: PaginationProps): import("theme-ui/jsx-runtime").JSX.Element;
export declare namespace Pagination {
    var Nav: typeof PaginationNav;
    var PaginationPageSizeSelect: typeof import("./PaginationPageSizeSelect").PaginationPageSizeSelect;
}
