import { HTMLAttributes } from 'react';
import { ResponsiveStyleValue } from 'theme-ui';
type QuoteSize = 'small' | 'medium' | 'large';
export type QuoteProps = {
    /** Size of the text between `small`, `medium` and `large`. Can be responsive with an array of values. Defaults to `medium`. */
    size?: ResponsiveStyleValue<QuoteSize>;
    /** The name of the quote's author. */
    author?: string;
    /** Extra information about the quote's author, e.g. their title and/or company. */
    authorInfo?: string;
    /** Whether to semantically render a callout instead of a quote. If `true`, the quotation marks and author are not rendered. */
    callout?: boolean;
} & HTMLAttributes<HTMLDivElement>;
/**
 * `Quote` v1.0
 *
 * Blockquote, with an optional author below it. Mainly used for marketing purposes.
 */
export declare const Quote: import("react").ForwardRefExoticComponent<{
    /** Size of the text between `small`, `medium` and `large`. Can be responsive with an array of values. Defaults to `medium`. */
    size?: ResponsiveStyleValue<QuoteSize>;
    /** The name of the quote's author. */
    author?: string | undefined;
    /** Extra information about the quote's author, e.g. their title and/or company. */
    authorInfo?: string | undefined;
    /** Whether to semantically render a callout instead of a quote. If `true`, the quotation marks and author are not rendered. */
    callout?: boolean | undefined;
} & HTMLAttributes<HTMLDivElement> & import("react").RefAttributes<HTMLDivElement>>;
export {};
